pub struct OpenAIClient { /* private fields */ }Implementations
Sourceimpl OpenAIClient
impl OpenAIClient
Sourcepub fn new(base_url: impl Into<String>) -> Result<Self>
pub fn new(base_url: impl Into<String>) -> Result<Self>
Create a new client with the specified base URL
Sourcepub fn with_api_key(
base_url: impl Into<String>,
api_key: impl Into<String>,
) -> Result<Self>
pub fn with_api_key( base_url: impl Into<String>, api_key: impl Into<String>, ) -> Result<Self>
Create a new client with the specified base URL and API key
Sourcepub async fn list_models(&self) -> Result<ChatModelResponse>
pub async fn list_models(&self) -> Result<ChatModelResponse>
get all models
Sourcepub async fn chat_completion(
&self,
request: ChatCompletionRequest,
) -> Result<ChatCompletionResponse>
pub async fn chat_completion( &self, request: ChatCompletionRequest, ) -> Result<ChatCompletionResponse>
Send a chat completion request
Sourcepub async fn chat_completion_stream(
&self,
request: ChatCompletionRequest,
) -> Result<impl Stream<Item = Result<ChatCompletionChunk>>>
pub async fn chat_completion_stream( &self, request: ChatCompletionRequest, ) -> Result<impl Stream<Item = Result<ChatCompletionChunk>>>
Send a streaming chat completion request